package org.jeecg.modules.adweb.seo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;

import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;

import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.adweb.seo.entity.HistoryReachStandardSite;
import org.jeecg.modules.adweb.seo.service.IHistoryReachStandardSiteService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.Arrays;

/**
 * @Description: 历史达标站点关键词达标数据表
 * @Author: jeecg-boot
 * @Date:   2024-10-16
 * @Version: V1.0
 */
@Tag(name="历史达标站点关键词达标数据表")
@RestController
@RequestMapping("/serp/historyReachStandardSite")
@Slf4j
public class HistoryReachStandardSiteController extends JeecgController<HistoryReachStandardSite, IHistoryReachStandardSiteService> {
	@Autowired
	private IHistoryReachStandardSiteService historyReachStandardSiteService;
	
	/**
	 * 分页列表查询
	 *
	 * @param historyReachStandardSite
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "历史达标站点关键词达标数据表-分页列表查询")
	@Operation(summary="历史达标站点关键词达标数据表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<HistoryReachStandardSite>> queryPageList(HistoryReachStandardSite historyReachStandardSite,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<HistoryReachStandardSite> queryWrapper = QueryGenerator.initQueryWrapper(historyReachStandardSite, req.getParameterMap());
		Page<HistoryReachStandardSite> page = new Page<HistoryReachStandardSite>(pageNo, pageSize);
		IPage<HistoryReachStandardSite> pageList = historyReachStandardSiteService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param historyReachStandardSite
	 * @return
	 */
	@AutoLog(value = "历史达标站点关键词达标数据表-添加")
	@Operation(summary="历史达标站点关键词达标数据表-添加")
	@PreAuthorize("@jps.requiresPermissions('serp:history_reach_standard_site:add')")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody HistoryReachStandardSite historyReachStandardSite) {
		historyReachStandardSiteService.save(historyReachStandardSite);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param historyReachStandardSite
	 * @return
	 */
	@AutoLog(value = "历史达标站点关键词达标数据表-编辑")
	@Operation(summary="历史达标站点关键词达标数据表-编辑")
    @PreAuthorize("@jps.requiresPermissions('serp:history_reach_standard_site:edit')")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody HistoryReachStandardSite historyReachStandardSite) {
		historyReachStandardSiteService.updateById(historyReachStandardSite);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "历史达标站点关键词达标数据表-通过id删除")
	@Operation(summary="历史达标站点关键词达标数据表-通过id删除")
    @PreAuthorize("@jps.requiresPermissions('serp:history_reach_standard_site:delete')")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		historyReachStandardSiteService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "历史达标站点关键词达标数据表-批量删除")
	@Operation(summary="历史达标站点关键词达标数据表-批量删除")
    @PreAuthorize("@jps.requiresPermissions('serp:history_reach_standard_site:deleteBatch')")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.historyReachStandardSiteService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "历史达标站点关键词达标数据表-通过id查询")
	@Operation(summary="历史达标站点关键词达标数据表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<HistoryReachStandardSite> queryById(@RequestParam(name="id",required=true) String id) {
		HistoryReachStandardSite historyReachStandardSite = historyReachStandardSiteService.getById(id);
		if(historyReachStandardSite==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(historyReachStandardSite);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param historyReachStandardSite
    */
    @PreAuthorize("@jps.requiresPermissions('serp:history_reach_standard_site:exportXls')")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HistoryReachStandardSite historyReachStandardSite) {
        return super.exportXls(request, historyReachStandardSite, HistoryReachStandardSite.class, "历史达标站点关键词达标数据表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @PreAuthorize("@jps.requiresPermissions('serp:history_reach_standard_site:importExcel')")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, HistoryReachStandardSite.class);
    }

}
