package org.jeecg.modules.adweb.seo.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.system.api.ISysBaseAPI;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.adweb.common.constant.AdwebConstant;
import org.jeecg.modules.adweb.common.util.ListUtil;
import org.jeecg.modules.adweb.seo.entity.SeoKpiStatistics;
import org.jeecg.modules.adweb.seo.entity.SeoPlanSubscription;
import org.jeecg.modules.adweb.seo.mapper.SeoKpiStatisticsMapper;
import org.jeecg.modules.adweb.seo.service.ISeoKpiStatisticsService;
import org.jeecg.modules.adweb.seo.service.ISeoPlanSubscriptionService;
import org.jeecg.modules.adweb.site.entity.AdwebSite;
import org.jeecg.modules.adweb.site.service.IAdwebSiteService;
import org.jeecg.modules.adweb.site.service.ISiteUserPermissionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import java.util.ArrayList;
import java.util.List;

/**
 * @Description: seo_kpi_statistics @Author: jeecg-boot @Date: 2024-10-09 @Version: V1.0
 */
@Service
@Slf4j
public class SeoKpiStatisticsServiceImpl
        extends ServiceImpl<SeoKpiStatisticsMapper, SeoKpiStatistics>
        implements ISeoKpiStatisticsService {

    @Autowired private IAdwebSiteService adwebSiteService;

    @Autowired private ISysBaseAPI sysBaseAPI;

    @Autowired private ISiteUserPermissionService siteUserPermissionService;

    @Autowired private ISeoPlanSubscriptionService seoPlanSubscriptionService;

    @Override
    public List<AdwebSite> getAllSites() {
        log.info("获取当前用户管理的 父 站点信息");
        List<AdwebSite> siteList = null;
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();

        QueryWrapper<AdwebSite> queryWrapper = new QueryWrapper<>();
        queryWrapper.select("id", "name", "code");
        queryWrapper.eq("site_type", AdwebConstant.SITE).orderByDesc("create_time");
        queryWrapper.eq("status", AdwebConstant.STATUS).isNull("parent_group_code");
        if (sysBaseAPI.isOem()) {
            List<String> oemGroupUids = sysBaseAPI.getOemGroupUids();
            List<String> codeList = siteUserPermissionService.getSiteCodeListByUids(oemGroupUids);
            queryWrapper.in("code", codeList);
        } else if (!sysBaseAPI.isAdmin()) {
            List<String> codeList = siteUserPermissionService.getSiteCodeList(sysUser.getId());
            queryWrapper.in("code", codeList);
        }
        siteList = adwebSiteService.list(queryWrapper);
        this.setPlanName(siteList);
        return siteList;
    }

    /** 放入营销方案名称 */
    private void setPlanName(List<AdwebSite> siteList) {
        if (ListUtil.isEmpty(siteList)) {
            return;
        }

        List<Integer> siteIds = new ArrayList<>();
        for (AdwebSite site : siteList) {
            siteIds.add(site.getId());
        }

        QueryWrapper<SeoPlanSubscription> historyQueryWrapper = new QueryWrapper<>();
        historyQueryWrapper.select("id", "plan_id", "site_id", "plan_name", "plan_type");
        historyQueryWrapper.in("site_id", siteIds);
        historyQueryWrapper.eq("status", 1);
        List<SeoPlanSubscription> histories = seoPlanSubscriptionService.list(historyQueryWrapper);
        if (ListUtil.isEmpty(histories)) {
            return;
        }

        for (AdwebSite site : siteList) {
            for (SeoPlanSubscription history : histories) {
                if (history.getSiteId().equals(site.getId() + "")) {
                    site.setPlanId(history.getPlanId());
                    site.setPlanName(history.getPlanName());
                    site.setHistoryId(history.getId());
                    site.setPlanType(history.getPlanType());
                }
            }
        }
    }
}
